@@ -433,12 +433,10 @@ pub struct MetaPath {
 
 #[derive(Debug, Default, PartialEq, Serialize)]
 pub struct MetaInfo {
-    #[serde(skip_serializing_if = "Option::is_none")]
-    pub title: Option<String>,
+    pub title: String,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub description: Option<String>,
-    #[serde(skip_serializing_if = "Option::is_none")]
-    pub version: Option<String>,
+    pub version: String,
 }
 
 #[derive(Debug, PartialEq, Serialize)]
